import random
import mset

WFHelperUI = mset.UIWindow("Warframe tint helper")
WFHelperUI.width = 300

def rV3():
    return [random.random(), random.random(), random.random()]

def setOneTint():   
    for x in mset.getSelectedMaterialGroup():
        x.extra.setField("Tint 0", cTintGlobal.color)
        x.extra.setField("Tint 1", cTintGlobal.color)
        x.extra.setField("Tint 2", cTintGlobal.color)
        x.extra.setField("Tint 3", cTintGlobal.color)
        x.extra.setField("Emissive low", cTintGlobal.color)
        x.extra.setField("Emissive high", cTintGlobal.color)

def updateTints():

    mSelectedMat = mset.getSelectedMaterial()
    #print("Copying from material", mSelectedMat.name)

    #if mset.getSelectedMaterial().getCustomShader() != "WarframePBR_2022.frag" and mset.getSelectedMaterial().getCustomShader() != "WarframeCharacter.frag":
    #    print("Error: Must be a Warframe material!")
    #    return

    if mSelectedMat.getGroup():
        
        for x in mset.getSelectedMaterialGroup():
            #if x != mSelectedMat:
                x.extra.setField("Tint 0", mSelectedMat.extra.getField("Tint 0"))
                x.extra.setField("Tint 1", mSelectedMat.extra.getField("Tint 1"))
                x.extra.setField("Tint 2", mSelectedMat.extra.getField("Tint 2"))
                x.extra.setField("Tint 3", mSelectedMat.extra.getField("Tint 3"))
                x.extra.setField("Emissive low", mSelectedMat.extra.getField("Emissive low"))
                x.extra.setField("Emissive high", mSelectedMat.extra.getField("Emissive high"))

def randomTints():
    #randomize first, then apply to group
    rT0 = rV3()
    rT1 = rV3()
    rT2 = rV3()
    rT3 = rV3()
    rEmL = rV3()
    rEmH = rV3()
    #if mset.getSelectedMaterial().getCustomShader() != "WarframePBR.frag" and mset.getSelectedMaterial().getCustomShader() != "WarframeCharacter.frag":
    #    print("Error: Must be a Warframe material!")
    #    return
    if mset.getSelectedMaterial().getGroup():
        
        for x in mset.getSelectedMaterialGroup():
            x.extra.setField("Tint 0", rT0)
            x.extra.setField("Tint 1", rT1)
            x.extra.setField("Tint 2", rT2)
            x.extra.setField("Tint 3", rT3)
            x.extra.setField("Emissive low", rEmL)
            x.extra.setField("Emissive high", rEmH)

    else: print("Error: Material must be in a group!")

def loadTextures():
    mat = mset.getSelectedMaterial()
    filepath = mset.showOpenFileDialog(["png"])
    suffix = filepath[len(filepath) - 6:len(filepath)]

    tSet = ["_n.png", "_d.png", "_s.png", "_r.png", "_e.png", "_t.png"]
    tFields = ["Normal map", "Base color map", "Specular map", "Roughness map", "Emissive map", "Tint map"]

    bCheck = False

    for x in tSet:
        if x in suffix:
            bCheck = True
    if bCheck == False:
        print("Not a Warframe texture")
        return
    
    for x in range(6):
        t = filepath.replace(suffix, tSet[x])
        #print("Material:", mat.name, "Shader:", mat.getCustomShader(), "setting texture", t, "into field", tFields[x])
        mat.extra.setField(tFields[x], t)
    
    mat.extra.getField("Base color map").sRGB = True
    mat.extra.getField("Emissive map").sRGB = True
    if mat.extra.getField("Emissive map"):
        mat.extra.setField("Use emissive", True)
    else:
        mat.extra.setField("Use emissive", False)

def exitPlugin():
    mset.shutdownPlugin()


WFHelperUI.clearElements()

bHelpLabel1 = mset.UILabel("Label1")
bHelpLabel1.text = """Tints are automatically copied from selected material 
to other materials within the same group"""
bHelpLabel1.fixedWidth = 300
WFHelperUI.addElement(bHelpLabel1)

WFHelperUI.addReturn()

mset.callbacks.onSceneChanged = updateTints

bRandomizeTints = mset.UIButton("Randomize group tints")
WFHelperUI.addElement(bRandomizeTints)
bRandomizeTints.onClick = randomTints

WFHelperUI.addReturn()

cTintGlobal = mset.UIColorPicker("Uniform tint")
WFHelperUI.addElement(cTintGlobal)

WFHelperUI.addReturn()

bSetTint = mset.UIButton("Apply to group")
WFHelperUI.addElement(bSetTint)
bSetTint.onClick = setOneTint

WFHelperUI.addReturn()

bLoadTex = mset.UIButton("Load textures into selected mat")
WFHelperUI.addElement(bLoadTex)
bLoadTex.onClick = loadTextures

WFHelperUI.addReturn()

#toolbag 3 plugin windows don't have a close button
if mset.getToolbagVersion() < 4000:
    bExitButton = mset.UIButton("Close")
    WFHelperUI.addElement(bExitButton)
    bExitButton.onClick = exitPlugin